/* Test suite for Circ.asy.
 *
 * Copyright (C) 2008-2009 W. Trevor King <wking@drexel.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

import Circ;

real u = 2cm, v=0;

write("resistor");
TwoTerminal Rn = resistor((0,v), 0, normal, "$R_{normal}$", "30\ohm");
dot("beg", Rn.beg, NW, red);
dot("end", Rn.end, NE, red);
dot("mid", Rn.mid, S, red);
TwoTerminal Rvb = resistor((2u,v), 0, variable, "$R_{variable}$", "30\kohm");
v -= u;

write("capacitor");
TwoTerminal Cn = capacitor((0,v), 0, normal, "$C_{normal}$", "30 $\mu$F");
TwoTerminal Ce = capacitor((u,v), 0, electrolytic, "$C_{electrolytic}$", "30 $\mu$F");
TwoTerminal Cvb = capacitor((2u,v), 0, variable, "$C_{variable}$", "30 $\mu$F");
TwoTerminal Cvt = capacitor((3u,v), 0, variant, "$C_{variant}$", "30 $\mu$F");
v -= u;

write("inductor");
TwoTerminal Lup = inductor((0,v), 0, Up, "$L_{Up}$", "30 H");
TwoTerminal Ldown = inductor((u,v), 0, Down, "$L_{Down}$", "30 H");
v -= u;

write("diode");
TwoTerminal Dn = diode((0,v), 0, normal, "$D_{normal}$", "1.3 V");
TwoTerminal Dz = diode((u,v), 0, zener, "$D_{zener}$", "1.3 V");
TwoTerminal Dled = diode((2u,v), 0, LED, "$D_{LED}$", "1.7 V");
v -= u;

write("battery");
TwoTerminal B = battery((0,v), 0, "Battery", "1.5 V");
v -= u;

write("switch");
TwoTerminal B = switchSPST((0,v), 0, NO, "$S_{NO}$", "Open");
TwoTerminal B = switchSPST((u,v), 0, NC, "$S_{NC}$", "Closed");
v -= u;

write("current");
TwoTerminal Icurr = current((0,v), 0, "I", "10 A");
v -= u;

write("source");
TwoTerminal Sdc = source((0,v), 0, DC, "DC", "5 V");
TwoTerminal Sac = source((u,v), 0, AC, "AC", "5 V$_{pp}$");
TwoTerminal Si = source((2u,v), 0, I, "I", "5 A");
TwoTerminal Sv = source((3u,v), 0, V, "V", "5 V");
v -= 1.5u;

write("positioning");
TwoTerminal Spos = source((u,v), 90, DC, "DC", "5 V");
TwoTerminal Rpos = resistor((0,0), 0, normal, "+offset", "5 \ohm", draw=false);
Rpos.centerto(Spos.beg, Spos.end, offset=u);
Rpos.draw();
dot("Sa", Spos.beg, S);
dot("Sb", Spos.end, N);
dot("Ra", Rpos.beg, S);
dot("Rb", Rpos.end, N);
TwoTerminal Cpos = capacitor((0,0), 0, normal, "-2offset", "4 F",draw=false);
Cpos.centerto(Spos.beg, Spos.end, offset=-2u);
Cpos.draw();
v -= u;

write("wires");
dot("nsq", (0,v), N);
dot("b", (u/2,v-u/2), S);
wire((0,v), (u/2,v-u/2), nsq);
dot("udsq", (u,v), N);
dot("b", (3u/2,v-u/2), S);
wire((u,v), (3u/2,v-u/2), udsq);
dot("rlsq", (2u,v), N);
dot("b", (5u/2,v-u/2), S);
wire((2u,v), (5u/2,v-u/2), rlsq);
dot("udsq w/d", (3u,v), N);
dot("b", (7u/2,v-u/2), S);
wire((3u,v), (7u/2,v-u/2), udsq, -u/4);
dot("rlsq w/d", (4u,v), N);
dot("b", (9u/2,v-u/2), S);
wire((4u,v), (9u/2,v-u/2), rlsq, u/4);
v -= u;

write("circuit");
v -= u/2;  // this circuit takes up more height than the previous lines.
TwoTerminal Ccirc = capacitor((0,v), ang=90);
TwoTerminal Rcirc = resistor(draw=false);
Rcirc.centerto(Ccirc.beg, Ccirc.end);
Rcirc.shift((u,0));  // gratuitous use of shift, but whatever...
Rcirc.draw();
// In the following, we assume the resistor is longer than the
// capacitor.  If that is not true, you can find the corners of the
// circuit programatically and use those corners.
wire(Rcirc.end, Ccirc.end, rlsq);
wire(Rcirc.beg, Ccirc.beg, rlsq);
pair Pcirc[] = {(Ccirc.beg.x,Rcirc.beg.y), (Ccirc.end.x,Rcirc.end.y),
		Rcirc.end, Rcirc.beg};
kirchhoff_loop(Pcirc);
v -= u;
