#!/usr/bin/python
#
# Convert e.g. graduate.xml from the department directory into my
# people XML format e.g. for TAs.xml.
#
# usage: ./department_xml_to_people.py graduate.xml | xml_pp > TAs.xml
#
# xml_pp is included in the Ubuntu xml-twig-tools package.

import elementtree.ElementTree as ET

def convert_file(infile, outfile):
    root = ET.Element("people")
    in_tree = ET.parse(infile)
    in_root = in_tree.getroot()
    for in_person in in_root.findall("person"):
        firstname = in_person.findtext("firstname")
        lastname = in_person.findtext("lastname")
        name_text =  "%s %s" % (firstname, lastname)
        email_text = in_person.findtext("email")
        email_text = email_text.replace(" [at] ", " at ")
        email_text = email_text.replace(".edu ", " dot edu")
        office_text = in_person.findtext("office")
        hours_text = None
        phone_text = in_person.findtext("phone")
        extension_text = phone_text.replace("(215) 895 - ","")
        url_text = in_person.findtext("webpage")
        picture_text = "/directory/graduate/small/%s.%s.jpg" \
            % (lastname.lower(), firstname.lower())

        person = ET.SubElement(root, "person")
        name = ET.SubElement(person, "name")
        name.text = name_text
        if email_text != None:
            email = ET.SubElement(person, "email")
            email.text = email_text
        if office_text != None:
            office = ET.SubElement(person, "office")
            office.text = office_text
        if hours_text != None:
            hours = ET.SubElement(person, "hours")
            hours.text = hours_text
        if extension_text != None:
            extension = ET.SubElement(person, "extension")
            extension.text = extension_text
        if url_text != None:
            url = ET.SubElement(person, "url")
            url.text = url_text
        if picture_text != None:
            picture = ET.SubElement(person, "picture")
            picture.text = picture_text
    tree = ET.ElementTree(root)
    tree.write(outfile)

if __name__ == "__main__":
    import sys

    #infile = sys.argv[1]
    #outfile = sys.argv[2]
    convert_file(sys.stdin, sys.stdout)
